@@ -1,12 +1,12 @@
 /*
-   Time-stamp: <98/03/05 09:23:29 yusuf>
+   Time-stamp: <98/06/07 12:36:01 yusuf>
 
-   $Id: backup.c,v 1.63 1998/03/05 01:29:38 yusuf Exp $	
+   $Id: backup.c,v 1.66 1998/06/07 04:45:15 yusuf Exp $	
 
 */
 
 #ifndef lint
-static char vcid[] = "$Id: backup.c,v 1.63 1998/03/05 01:29:38 yusuf Exp $";
+static char vcid[] = "$Id: backup.c,v 1.66 1998/06/07 04:45:15 yusuf Exp $";
 #endif /* lint */
 
 
@@ -497,12 +497,15 @@ PRIVATE void backup_alarm(int sig)
 
     char s[200], s1[200], s2[200], s3[200];
     time_t t_elapsed;
+static int prop= 0;
+static char propchar[] = "-/|\\";
     
     signal(SIGALRM, SIG_IGN);	 /* reset alarm */
     if (!other_mes) {
 	t_elapsed=s_tcurrent-s_tstart;
 	status_box(s_mes, s_idata.name, 0, FALSE, 1);
-	sprintf(s, "File %d of %d",  s_count, s_noarchive);
+	sprintf(s, "File %d of %d (%c)",  s_count, s_noarchive, propchar[prop]);
+        prop++; prop &=3;
 	status_box(s_mes, s, 2, FALSE, 1);
 	sprintf(s, "Processed %s of %s", print_kb(s2, bytes_processed), 
 		print_kb(s3, total_selected));
@@ -540,6 +543,7 @@ PRIVATE void backup_alarm(int sig)
 	}
     }
     signal(SIGALRM, backup_alarm);	 /* reset alarm */
+    retrigger_alarm();
 }
 
 
@@ -801,18 +805,43 @@ _errstat  do_backup(void) {
 }
 
 
+_errstat add_to_set(char *ln, char inc_or_exc)
+{
+    /* Adds line 's' to backup set */
+    
+    struct direntry entry;
+
+    if (!chk_sel_excl(ln)) {
+	if (get_statinfo(ln, &entry.info) != -1) {/* ignore if error */
+	    if (inc_or_exc == ENTRY_INCLUDE) {
+		select_entry_1(&entry, ln);
+		write(mf, "  Selected ", strlen("  Selected "));
+	    }
+	    else {
+		exclude_entry_1(&entry, ln);
+		write(mf, "  Excluded ", strlen("  Excluded "));
+	    }
+	    write(mf, ln, strlen(ln));
+	    write(mf, " from fileset\n", strlen(" from fileset\n"));
+	}
+	else
+	    return -1;
+    }
+    return 0;
+}
+
+
 _errstat read_in_fileset(int argc, char *argv[])
 {
-/* Reads in the files
+    /* Reads in the files
 
-   Returns 1 if all OK
-           -1 otherwise
-
- */
+       Returns 1 if all OK
+       -1 otherwise
+       
+    */
     FILE *f;
     char ln[MAX_FNAME], s[MAX_FNAME];
     _s32 c;
-    struct direntry entry;
     time_t t;
     _s8  inc_or_exc;
     
@@ -820,64 +849,56 @@ _errstat read_in_fileset(int argc, char *argv[])
     while (c < argc) {
 	if ( (!strcmp(argv[c], "-U") ||
 	      (!strcmp(argv[c], "-unattended-file"))) ) {
-		  c++;
-		  if (c == argc) {
-		      strcpy(ln, "Illegal file/directory/set name specified\n");
-		      write(mf, ln, strlen(ln));
-		      strcpy(ln, "BACKUP ABORTED\n");
-		      write(mf, ln, strlen(ln));
-		      return -1;
-		  }
-		  if (*argv[c] == '@') {
-		      strcpy(dir_cur_dir, taper_info_files);
-		      f = backrest_restore_backupset(&argv[c][1]);/* open file set */
-		      if (f==NULL) {
-			  sprintf(ln, "WARNING: Couldn't open file set %s\n", &argv[c][1]);
-			  write(mf, ln, strlen(ln));
-			  continue;
-		      }
-		      sprintf(ln, "Using file set %s\n", &argv[c][1]);
-		      write(mf, ln, strlen(ln));
-		      while (!feof(f)) {
-			  if (get_line(ln, f) == NULL) break;	 /* EOF */
-			  if ((*ln != 'E') && (*ln != 'I')) {
-			      strcpy(ln, "Illegal line in backup set - using old format?\n");
-			      write(mf, ln, strlen(ln));
-			      strcpy(ln, "BACKUP ABORTED\n");
-			      write(mf, ln, strlen(ln));
-			      fclose(f);
-			      return -1;
-			  }
-			  inc_or_exc = (*ln == 'I') ? ENTRY_INCLUDE : ENTRY_EXCLUDE;
-			  if (get_line(ln, f) == NULL) break;
-			  if (!chk_sel_excl(ln)) {
-			      if (get_statinfo(ln, &entry.info) != -1) {/* ignore if error */
-				  if (inc_or_exc == ENTRY_INCLUDE) {
-				      select_entry_1(&entry, ln);
-				      write(mf, "  Selected ", strlen("  Selected "));
-				  }
-				  else {
-				      exclude_entry_1(&entry, ln);
-				      write(mf, "  Excluded ", strlen("  Excluded "));
-				  }
-				  write(mf, ln, strlen(ln));
-				  write(mf, " from fileset\n", strlen(" from fileset\n"));
-			      }
-			      else {
-				  sprintf(s, "WARNING: %s is not found in fileset %s\n", ln, &argv[c][1]);
-				  write(mf, s, strlen(s));
-			      }
-			  }
-		      }
-		      fclose(f);
-		  }
+	    c++;
+	    if (c == argc) {
+		strcpy(ln, "Illegal file/directory/set name specified\n");
+		write(mf, ln, strlen(ln));
+		strcpy(ln, "BACKUP ABORTED\n");
+		write(mf, ln, strlen(ln));
+		return -1;
+	    }
+	    if (*argv[c] == '@') {
+		strcpy(dir_cur_dir, taper_info_files);
+		f = backrest_restore_backupset(&argv[c][1]);/* open file set */
+		if (f==NULL) {
+		    sprintf(ln, "WARNING: Couldn't open file set %s\n", &argv[c][1]);
+		    write(mf, ln, strlen(ln));
+		    continue;
+		}
+		sprintf(ln, "Using file set %s\n", &argv[c][1]);
+		write(mf, ln, strlen(ln));
+		while (!feof(f)) {
+		    if (get_line(ln, f) == NULL) break;	 /* EOF */
+		    if ((*ln != 'E') && (*ln != 'I')) {
+			strcpy(ln, "Illegal line in backup set - using old format?\n");
+			write(mf, ln, strlen(ln));
+			strcpy(ln, "BACKUP ABORTED\n");
+			write(mf, ln, strlen(ln));
+			fclose(f);
+			return -1;
+		    }
+		    inc_or_exc = (*ln == 'I') ? ENTRY_INCLUDE : ENTRY_EXCLUDE;
+		    if (get_line(ln, f) == NULL) break;
+		    if (add_to_set(ln, inc_or_exc) == -1) {
+			sprintf(s, "WARNING: %s is not found in fileset %s\n", ln, &argv[c][1]);
+			write(mf, s, strlen(s));
+		    }
+		}
+		fclose(f);
+	    }
+	    else {				 /* individual directory specified */
+		if (add_to_set(argv[c], ENTRY_INCLUDE) == -1) {
+		    sprintf(s, "WARNING: %s is not found\n", ln);
+		    write(mf, s, strlen(s));
+		    }
+	    }
 	}
 	c++;
     }
     time(&t);
     sprintf(ln, "\nBackup commenced at %s\n", ctime(&t));
     write(mf, ln, strlen(ln));
-
+    
     if ((unattended_id != -1)) {		 /* unattended backup and user */
 	if (unattended_id != tdh.archive_id) {	 /* wants to append to a particular one */
 	    sprintf(s, "Archive %d is in tape drive. I want archive %d\n",
@@ -891,7 +912,6 @@ _errstat read_in_fileset(int argc, char *argv[])
     }
     return 1;
 }
-
    
 _errstat utils_write_nullheader(WINDOW **mes);
 _errstat check_backup(void) {
