@@ -1,12 +1,12 @@
 /*
-   Time-stamp: <98/03/05 09:27:00 yusuf>
+   Time-stamp: <98/04/07 09:52:44 yusuf>
 
-   $Id: bg_backup.c,v 1.11 1998/03/05 01:29:38 yusuf Exp $	
+   $Id: bg_backup.c,v 1.12 1998/05/02 12:51:40 yusuf Exp $	
 
 */
 
 #ifndef lint
-static char vcid[] = "$Id: bg_backup.c,v 1.11 1998/03/05 01:29:38 yusuf Exp $";
+static char vcid[] = "$Id: bg_backup.c,v 1.12 1998/05/02 12:51:40 yusuf Exp $";
 #endif /* lint */
 
 
@@ -153,11 +153,14 @@ _s32 free_space()
 {
 /* Returns the number of K of diskspace free */
     struct statfs st;
-    
+
     if (statfs(temp_dir, &st) < 0) return -1;
-    if (st.f_bsize > 1024) return st.f_bavail * (st.f_bavail / 1024);
-    else if (st.f_bsize < 1024) return st.f_bavail / (1024 / st.f_bavail);
-    return st.f_bavail;
+    if (st.f_bsize == 1024)
+	return st.f_bavail;
+    return st.f_bsize * (st.f_bavail / 1024) + st.f_bavail%1024 * st.f_bsize / 1024;
+/* the available sectors / 1024 gives the K of sectors free, times bytes
+per sector gives KB free, add that to the remainder of sectors free
+we didn't count times the bytes per sector convert it to KB */
 }
 
 int main(int argc, char *argv[])
