@@ -1,12 +1,12 @@
 /*
-   Time-stamp: <97/05/31 17:59:42 yusuf>
+   Time-stamp: <98/06/07 12:15:39 yusuf>
 
-   $Id: bg_restore.c,v 1.7 1997/05/31 10:32:49 yusuf Exp $	
+   $Id: bg_restore.c,v 1.8 1998/06/07 04:19:42 yusuf Exp $	
 
 */
 
 #ifndef lint
-static char vcid[] = "$Id: bg_restore.c,v 1.7 1997/05/31 10:32:49 yusuf Exp $";
+static char vcid[] = "$Id: bg_restore.c,v 1.8 1998/06/07 04:19:42 yusuf Exp $";
 #endif /* lint */
 
 
@@ -104,7 +104,10 @@ int main(int argc, char *argv[])
 	}
 	goto fin;
     }
-    
+
+#ifdef FIFO_PROBLEMS
+    sleep(10);
+#endif    
     while (!stop_child) {
  	if (fifo_receive_file_with_info (fdfifo, &fi, &s, &ff)) /* get file data */
  		break;
