@@ -1,12 +1,12 @@
 /*
-   Time-stamp: <96/08/05 19:30:36 yusuf>
+   Time-stamp: <97/08/11 18:23:38 yusuf>
 
-   $Id: bg_vars.c,v 1.9 1996/08/05 19:02:00 yusuf Exp $	
+   $Id: bg_vars.c,v 1.15 1997/08/11 12:32:04 yusuf Exp $	
 
 */
 
 #ifndef lint
-static char vcid[] = "$Id: bg_vars.c,v 1.9 1996/08/05 19:02:00 yusuf Exp $";
+static char vcid[] = "$Id: bg_vars.c,v 1.15 1997/08/11 12:32:04 yusuf Exp $";
 #endif /* lint */
 
 
@@ -44,10 +44,11 @@ struct err_temp errs[] = {
     {ERROR_OPENING_FIFO, "opening FIFO", FALSE, FALSE},
     {ERROR_UNABLE_FORK, "forking child", FALSE, FALSE},
     {ERROR_OPENING_SET, "opening file set", FALSE, FALSE},
+    {ERROR_CREATING_SET, "creating file set", FALSE, FALSE},
     {ERROR_INFO_ISNT_DIR, "Info file directory is not a directory", TRUE, FALSE},
     {ERROR_OPENING_MAIL, "opening mail file", FALSE, FALSE},
-    {ERROR_GETTING_BLKSIZE, "setting block size", FALSE, FALSE},
-    {ERROR_SETTING_BLKSIZE, "getting block size", FALSE, FALSE},
+    {ERROR_GETTING_BLKSIZE, "getting block size", FALSE, FALSE},
+    {ERROR_SETTING_BLKSIZE, "setting block size", FALSE, FALSE},
     {ERROR_SETTING_SHARED_MEM, "setting up shared memory", FALSE, FALSE},
     {ERROR_NO_TAPE_TYPE, "Set tape drive using -T option", TRUE, TRUE},
     {ERROR_PREF_FORMAT, "Error in preference file format", TRUE, TRUE},
@@ -70,7 +71,10 @@ struct err_temp errs[] = {
     {ERROR_SEMAPHORE_ACTION, "activating semaphore", FALSE, FALSE},  
     {ERROR_CHILD_SEGFAULT, "Write child seg faulted", TRUE, FALSE},  
     {ERROR_TAPE_EOM, "doing eom", FALSE, FALSE},
-    {ERROR_TAPE_GOTO, "positining tape", FALSE, FALSE},  
+    {ERROR_TAPE_GOTO, "positining tape", FALSE, FALSE},
+    {ERROR_UNCOMPRESSING_INFO, "uncompressing info files", FALSE, FALSE},
+    {ERROR_STACKOVER, "Stack overflow", TRUE, FALSE},  
+    {ERROR_ILLEGALBACKUPSET, "Illegal backup set", TRUE, FALSE},  
     {ERROR_NONE, "", TRUE, TRUE},
     {0, "", TRUE, TRUE}
 };
@@ -84,12 +88,13 @@ char *tr_buffer=NULL;				 /* transfer buffer */
 
 char log_file[MAX_FNAME]={0};			 /* log file stuff */
 int  log_level=2;
-char exclude_compress[MAX_FNAME]={".gz .gif .Z .zip .jpg .jpeg .rpm .deb .tgz .taz"};/* files to exclude in compression */
+char exclude_compress[MAX_FNAME]={".gz .gif .Z .zip .jpg .bmp"};/* files to exclude in compression */
 char temp_dir[MAX_FNAME]={"/usr/tmp"};		 /* temporary files directory */
 int  ovrwrite=1;
 int  max_tr_size=DEFAULT_TR_SIZE;		 /* is used for reading/writing files to/from hard disk */
 _s32 min_free=COMPRESS_MIN_FREE;
 int  min_seek=DEFAULT_MIN_SEEK;			 /* min blocks to pass before seeking */
+int  set_owner=TRUE;
 
 int lf=0;					 /* log file */
 UBYTE *cbuf;					 /* compression buffer */
