@@ -1,12 +1,13 @@
-/*
-   Time-stamp: <98/03/03 12:30:51 yusuf>
 
-   $Id: common.c,v 1.74 1998/03/03 04:35:10 yusuf Exp $	
+/*
+   Time-stamp: <99/05/12 19:07:35 yusuf>
+
+   $Id: common.c,v 1.77.2.2 1999/05/12 11:09:17 yusuf Exp $	
 
 */
 
 #ifndef lint
-static char vcid[] = "$Id: common.c,v 1.74 1998/03/03 04:35:10 yusuf Exp $";
+static char vcid[] = "$Id: common.c,v 1.77.2.2 1999/05/12 11:09:17 yusuf Exp $";
 #endif /* lint */
 
 
@@ -222,15 +223,18 @@ _errstat search_file(char *s, _s32 vol, struct info_file_data *i_data)
  */
     struct info_file_key i_key;
     int com=TRAVERSE_SEARCH;
+    char fn[MAX_FNAME];
 
     if (!info_fd) return -1;       /* no info file - ie. new archive */
     strcpy(i_data->name, s);
     fill_info_key(*i_data, &i_key);
+    i_key.fname_pos = -1; strcpy(blank_fname, s);
     while (1) {
 	if (ntraverse(0, &i_key, NULL, &i_data->recnum, com, INFO_NAME) == 2)
 	    return  -1;				 /* error traversing */
 	com = TRAVERSE_CONTINUE;
-	if (strcmp(i_key.name, s)) return -1;	 /* didn't find it */
+	if (read_info_filename(i_key.fname_pos, fn) == -1) return -1;
+	if (strcmp(fn, s)) return -1;	 /* didn't find it */
 	if (i_key.pos_in_archive == 0) return -1; /* not in archive */
 	if (!vol || (abs(i_key.volume) == vol)) {
 		if (read_info_rec(i_data->recnum, i_data) == -1)
@@ -273,8 +277,8 @@ _errstat find_most_recents()
 	}
 	com = TRAVERSE_CONTINUE;
 	if (i_key.pos_in_archive == 0) continue;
-	if (prev.name) {
-	    if (strcmp(prev.name, i_key.name)) {
+	if (prev.fname_pos) {
+	    if (prev.fname_pos != i_key.fname_pos) {
 		for (c=0; c<prev_count; c++) 
 		    (m_files+prevs[c])->most_recent = last.recnum;
 		prev = i_key;
@@ -1257,7 +1261,7 @@ void print_my_name()
     char s[100];
     
     if (no_windows) return;
-    sprintf(s, "Taper %s by Yusuf Nagree (yusuf@multiline.com.au)", CUR_VERSION);
+    sprintf(s, "Taper %s by Yusuf Nagree (yusuf@omen.net.au)", CUR_VERSION);
     centre(bottom, 0, s, COLOR_BOTTOM);
     wrefresh(bottom);
 }
@@ -1854,18 +1858,83 @@ _errstat write_info_rec(_s32 rec, struct info_file_data *i_data)
 /* Writes i_data in the main inf file
 
    Returns -1 if error, 0 otherwise
- */
-    struct info_file_data i_data1;
 
-    i_data->recnum = rec;			 /* to be safe */
-    i_data1 = *i_data;
+   NOTE: Once a filename has been written once, it can never
+   change!
+ */
+    struct file_info_file_data i_data1;
+    off_t l;
+    _u32 fl;
+    
+    i_data1.recnum = rec;
+    i_data1.f = i_data->f;
+    if (!i_data->fname_pos) {			 /* filename needs to be */
+	l = lseek(info_index[2], 0L, SEEK_END);	 /*  to filename file */
+	i_data->fname_pos = l;			 /*  at end of file */
+	fl = strlen(i_data->name);		 /* write filename length */
+	if (write_u32(info_index[2], &fl) == -1) return -1;
+	if (write(info_index[2], i_data->name, fl) == -1) return -1;
+    }
+    i_data1.fname_pos = i_data->fname_pos;
     fi_endianize2little(&i_data->f, &i_data1.f);
-    lseek(info_index[0], (long) ((rec+1)*sizeof(*i_data)), SEEK_SET);
-    if (write(info_index[0], &i_data1, sizeof(*i_data)) == -1) return -1;
+    lseek(info_index[0], (long) ((rec+1)*sizeof(i_data1)), SEEK_SET);
+    if (write(info_index[0], &i_data1, sizeof(i_data1)) == -1) return -1;
     return 0;
 }
 
 
+_errstat read_info_filename(off_t pos, char *name)
+{
+    /* Reads in the filename that for i_data
+
+       Returns -1 if error, 0 otherwise */
+
+    _u32 fl;
+    
+    lseek(info_index[2], pos, SEEK_SET);	 /* now read in filename */
+    if (read_u32(info_index[2], &fl) == -1) return -1;
+    if (read(info_index[2], name, fl) ==-1) return -1;
+    name[fl]=0;					 /* terminator */
+    return 0;
+}
+
+
+char *get_fn1(off_t pos)
+{
+    /* reads in the filename at offset 'pos' and
+       returns a static string to it */
+
+    static char s[MAX_FNAME];
+
+    switch(pos) {
+    case -1:
+	strcpy(s, blank_fname); break;
+    case 0:
+	strcpy(s, ""); break;
+    default:
+	read_info_filename(pos, s); break;
+    }
+    return s;
+}
+
+char *get_fn2(off_t pos)
+{
+    /* reads in the filename at offset 'pos' and
+       returns a static string to it */
+
+    static char s[MAX_FNAME];
+    
+    switch(pos) {
+    case -1:
+	strcpy(s, blank_fname); break;
+    case 0:
+	strcpy(s, ""); break;
+    default:
+	read_info_filename(pos, s); break;
+    }
+    return s;
+}
+
 _errstat read_info_rec(_s32 rec, struct info_file_data *i_data)
 {
 /* Reads i_data in the main inf file
@@ -1873,13 +1942,15 @@ _errstat read_info_rec(_s32 rec, struct info_file_data *i_data)
    Returns -1 if error, 0 otherwise
  */
 
-    struct info_file_data i_data1;
+    struct file_info_file_data i_data1;
     
-    lseek(info_index[0], (long) ((rec+1)*sizeof(*i_data)), SEEK_SET);
-    if (read(info_index[0], &i_data1, sizeof(*i_data)) == -1) return -1;
-    *i_data = i_data1;
+    lseek(info_index[0], (long) ((rec+1)*sizeof(i_data1)), SEEK_SET);
+    if (read(info_index[0], &i_data1, sizeof(i_data1)) == -1) return -1;
+    i_data->recnum = i_data1.recnum;
+    i_data->f = i_data1.f;
+    i_data->fname_pos = i_data1.fname_pos;
     fi_endianize2mach(&i_data1.f, &i_data->f);
-    return 0;
+    return read_info_filename(i_data->fname_pos, i_data->name);
 }
 
 
@@ -1892,7 +1963,7 @@ void fill_info_key(struct info_file_data i_data, struct info_file_key *i_key)
     i_key->mtime = i_data.f.mtime;
     i_key->pos_in_archive = i_data.f.pos_in_archive;
     i_key->recnum = i_data.recnum;
-    strcpy(i_key->name, i_data.name);
+    i_key->fname_pos = i_data.fname_pos;
 }
 
 _errstat add_to_info_index(struct info_file_data *id)
@@ -1904,7 +1975,7 @@ _errstat add_to_info_index(struct info_file_data *id)
     int x;
     
     fill_info_key(*id, &i_key);
-    for (x=0; x<INFO_INDICIES; x++) 		 /* add to recnumes */
+    for (x=0; x<INFO_INDICIES-1; x++) 		 /* add to recnumes */
 	insertb(0, &i_key, x);
     return 0;
 }
@@ -2231,7 +2302,8 @@ _errstat open_info_file(char must_exist, _u32 archive_id, _s8 open_recnum)
 
        taper_xxxxx     = file that contains header info + vol header
        taper_xxxxx.0   = file with file_info (main file)
-       taper_xxxxx.1  )
+       taper_xxxxx.1   = index file
+       taper_xxxxx.2   = filename file - text file containing filenames
 
    If open_recnum, then recnum file is opened, otherwise not
    
@@ -2312,6 +2384,7 @@ void del_info_file(_u32 archive_id)
 
 void set_1s_timer()
 {
+#ifdef BSD_SIGNALS
     /* Sets a 1 second timer */    
     struct itimerval itv1;
     struct timeval itv, val;
@@ -2323,11 +2396,15 @@ void set_1s_timer()
     itv1.it_value = val;
     itv1.it_interval = itv;
     setitimer(ITIMER_REAL, &itv1, NULL);
+#else
+    alarm(1);
+#endif
 }
 
 
 void reset_timer()
 {
+#ifdef BSD_SIGNALS
     /* Clears timer * - all resets signal handler */
     struct itimerval itv1;
     struct timeval itv, val;
@@ -2339,10 +2416,21 @@ void reset_timer()
     itv1.it_value = val;
     itv1.it_interval = itv;
     setitimer(ITIMER_REAL, &itv1, NULL);
+#else
+    alarm(0);
+#endif
     signal(SIGALRM, SIG_DFL);
 }
 
 
+void retrigger_alarm()
+{
+#ifndef BSD_SIGNALS
+    alarm(1);
+#endif
+}
+
+
 _s8 chk_sel_excl(char *s)
 {
     /* See if 's' is in the exclusion or inclusion list
@@ -2383,3 +2471,12 @@ char *get_line(char *s, FILE *f)
 }
 
 
+void strip_trailing_spaces(char *s)
+{
+    char *s1=&s[strlen(s)]-1;
+
+    while ((*s1 == ' ') && (s1 >= s)) {
+	*s1 = 0;
+	s1--;
+    }
+}
