@@ -1,3 +1,16 @@
+/*
+   Time-stamp: <96/07/19 20:14:20 yusuf>
+
+   $Id: deflate.c,v 1.16 1996/07/27 20:42:28 yusuf Exp $	
+
+*/
+
+#ifndef lint
+static char vcid[] = "$Id: deflate.c,v 1.16 1996/07/27 20:42:28 yusuf Exp $";
+#endif /* lint */
+
+
+
 /* This module of code has been shamelessley ripped off from the
  * GNU gzip package - version 1.2.4.
  * 
@@ -85,7 +98,7 @@
 #include "lzw.h" /* just for consistency checking */
 
 #ifdef RCSID
-static char rcsid[] = "$Id: deflate.c,v 0.15 1993/06/24 10:53:53 jloup Exp $";
+static char rcsid[] = "$Id: deflate.c,v 1.16 1996/07/27 20:42:28 yusuf Exp $";
 #endif
 
 /* ===========================================================================
