@@ -1,7 +1,7 @@
 /*
-   Time-stamp: <96/07/19 20:15:22 yusuf>
+   Time-stamp: <97/04/20 09:47:46 yusuf>
 
-   $Id: gzip.h,v 1.3 1996/07/27 20:42:29 yusuf Exp $	
+   $Id: gzip.h,v 1.5 1997/04/20 08:03:31 yusuf Exp $	
 
 */
 
@@ -46,7 +46,11 @@
  * too often
  */
 #include <stdio.h>
-#include <string.h>
+#ifdef ASM_STRING
+  #include <linux/string.h>
+#else
+  #include <string.h>
+#endif
 #include <memory.h>
 #define memzero(s, n)     memset ((voidp)(s), 0, (n))
 
