@@ -1,3 +1,16 @@
+/*
+   Time-stamp: <96/07/19 20:14:28 yusuf>
+
+   $Id: inflate.c,v 1.16 1996/07/27 20:42:30 yusuf Exp $	
+
+*/
+
+#ifndef lint
+static char vcid[] = "$Id: inflate.c,v 1.16 1996/07/27 20:42:30 yusuf Exp $";
+#endif /* lint */
+
+
+
 /* This module of code has been shamelessley ripped off from the
  * GNU gzip package - version 1.2.4.
  * 
@@ -114,7 +127,7 @@
  */
 
 #ifdef RCSID
-static char rcsid[] = "$Id: inflate.c,v 0.14 1993/06/10 13:27:04 jloup Exp $";
+static char rcsid[] = "$Id: inflate.c,v 1.16 1996/07/27 20:42:30 yusuf Exp $";
 #endif
 
 #include <sys/types.h>
