@@ -1,3 +1,16 @@
+/*
+   Time-stamp: <96/07/19 20:14:31 yusuf>
+
+   $Id: lzrw3.c,v 1.2 1996/07/27 20:42:31 yusuf Exp $	
+
+*/
+
+#ifndef lint
+static char vcid[] = "$Id: lzrw3.c,v 1.2 1996/07/27 20:42:31 yusuf Exp $";
+#endif /* lint */
+
+
+
 /*
  claus
  *
