@@ -1,3 +1,16 @@
+/*
+   Time-stamp: <96/07/19 20:14:41 yusuf>
+
+   $Id: trees.c,v 1.16 1996/07/27 20:42:32 yusuf Exp $	
+
+*/
+
+#ifndef lint
+static char vcid[] = "$Id: trees.c,v 1.16 1996/07/27 20:42:32 yusuf Exp $";
+#endif /* lint */
+
+
+
 /* This module of code has been shamelessley ripped off from the
  * GNU gzip package - version 1.2.4.
  * 
@@ -76,7 +89,7 @@
 #include "gzip.h"
 
 #ifdef RCSID
-static char rcsid[] = "$Id: trees.c,v 0.12 1993/06/10 13:27:54 jloup Exp $";
+static char rcsid[] = "$Id: trees.c,v 1.16 1996/07/27 20:42:32 yusuf Exp $";
 #endif
 
 /* ===========================================================================
