@@ -1,12 +1,12 @@
 /*
-   Time-stamp: <97/04/19 20:56:43 yusuf>
+   Time-stamp: <98/05/02 07:12:25 yusuf>
 
-   $Id: endianize.c,v 1.8 1997/04/19 13:05:23 yusuf Exp $	
+   $Id: endianize.c,v 1.9 1998/05/02 12:51:41 yusuf Exp $	
 
 */
 
 #ifndef lint
-static char vcid[] = "$Id: endianize.c,v 1.8 1997/04/19 13:05:23 yusuf Exp $";
+static char vcid[] = "$Id: endianize.c,v 1.9 1998/05/02 12:51:41 yusuf Exp $";
 #endif /* lint */
 
 
@@ -225,7 +225,7 @@ void tape_header_endianize2mach(struct tape_header *t)
 void mach2littlekey(struct info_file_key *k, struct info_file_key *k1)
 {
     k1->recnum = mach2littleu32(&k->recnum);
-    strcpy(k1->name, k->name);
+    k1->fname_pos = mach2littleu32(&k->fname_pos);
     k1->volume = mach2littleu32(&k->volume);
     k1->pos_in_archive = mach2littleu32(&k->pos_in_archive);
     k1->mtime = mach2littletime(&k->mtime);
@@ -234,7 +234,7 @@ void mach2littlekey(struct info_file_key *k, struct info_file_key *k1)
 void little2machkey(struct info_file_key *k, struct info_file_key *k1)
 {
     k1->recnum = little2machu32(&k->recnum);
-    strcpy(k1->name, k->name);
+    k1->fname_pos = little2machu32(&k->fname_pos);
     k1->volume = little2machu32(&k->volume);
     k1->pos_in_archive = little2machu32(&k->pos_in_archive);
     k1->mtime = little2machtime(&k->mtime);
