@@ -1,5 +1,5 @@
 /*
-   Time-stamp: <96/08/05 19:24:02 yusuf>
+   Time-stamp: <97/08/11 18:23:19 yusuf>
 */   
 
 
@@ -63,6 +63,9 @@
 #define ERROR_CHILD_SEGFAULT -55		 /* Write child ended in seg fault */
 #define ERROR_TAPE_EOM -56			 /* Error doing eom */
 #define ERROR_TAPE_GOTO -57			 /* Positioning on a block */
+#define ERROR_UNCOMPRESSING_INFO -58		 /* Uncompressing info */
+#define ERROR_STACKOVER -59			 /* Stack overflow */
+#define ERROR_ILLEGALBACKUPSET -60		 /* Illegal backup set */
 #define ERROR_NONE -99				 /* no error - clean exit */
 						 
 						 
@@ -76,3 +79,4 @@ struct err_temp {
 };
 
 extern struct err_temp errs[];
+
