@@ -30,7 +30,6 @@ extern char *fgetsz (char *s, int size, FILE *stream)
 		    c = getc (stream);		 
 		    if (c == EOF) {		 /* error */
 			*p = '\0';
-			if (p == s) return NULL; /* couldn't get anything */
 			if (ferror(stream)) {	 /* error on stream */
 			    if (errno == EINTR) { /* if error is signal interrupt */
 				wait++;	
@@ -42,7 +41,7 @@ extern char *fgetsz (char *s, int size, FILE *stream)
 			    else
 				return NULL;	 /* other errors are errors */
 			}
-			return s;		 /* end of file */
+			return (p == s) ? NULL : s; /* end of file */
 		    }
 		    else
 			break;
