@@ -1,13 +1,17 @@
 /*
-   Time-stamp: <96/07/19 20:17:50 yusuf>
+   Time-stamp: <97/04/20 09:48:17 yusuf>
 
-   $Id: memory.h,v 1.6 1996/07/27 20:42:10 yusuf Exp $
+   $Id: memory.h,v 1.7 1997/04/20 02:00:04 yusuf Exp $
 */
 
 
 
 #include <stdlib.h>
-#include <string.h>
+#ifdef ASM_STRING
+  #include <linux/string.h>
+#else
+  #include <string.h>
+#endif
 
 void init_memory(void);
 void *my_malloc(size_t size);
