@@ -1,13 +1,13 @@
 
 /*
-   Time-stamp: <97/07/06 12:14:54 yusuf>
+   Time-stamp: <98/05/02 19:50:30 yusuf>
 
-   $Id: restore.c,v 1.53 1997/07/06 04:26:25 yusuf Exp $	
+   $Id: restore.c,v 1.54 1998/05/02 12:51:41 yusuf Exp $	
 
 */
 
 #ifndef lint
-static char vcid[] = "$Id: restore.c,v 1.53 1997/07/06 04:26:25 yusuf Exp $";
+static char vcid[] = "$Id: restore.c,v 1.54 1998/05/02 12:51:41 yusuf Exp $";
 #endif /* lint */
 
 
@@ -691,9 +691,10 @@ PRIVATE void print_voldir(void)
     for (x=0; x<ifd.no_in_archive; x++) {
 	read_info_rec(x, &i_data);
 	if (i_data.f.pos_in_archive) {
-	    pr_filename(i_data.name, s, 25);
 	    t = *localtime(&i_data.f.backup_time);
-	    printf("%-25s %3d %5d %2d/%2d/%2d %2d:%02d %12s %12s\n", s, abs(i_data.f.volume), i_data.f.pos_in_archive,t.tm_mday,
+	    printf("%-25s %3d %5d %2d/%2d/%2d %2d:%02d %12s %12s\n",
+		   trunc_filename(i_data.name, s, 25),
+		   abs(i_data.f.volume), i_data.f.pos_in_archive,t.tm_mday,
 		   t.tm_mon+1, t.tm_year, t.tm_hour, t.tm_min, convert(s1, i_data.f.size),
 		   convert(s2, i_data.f.act_size));
 	    c_sz += i_data.f.act_size;
@@ -729,9 +730,11 @@ PRIVATE void print_voldir(void)
     while (!x) {
 	read_info_rec(c, &i_data);
 	if (i_data.f.pos_in_archive) {
-	    strcpy(s, i_data.name); s[22] = 0;
+	    trunc_filename(i_data.name, s, 25);
 	    t = *localtime(&i_data.f.backup_time);
-	    printf("%-25s %3d %5d %2d/%2d/%2d %2d:%02d %12s %12s\n", s, abs(i_data.f.volume), i_data.f.pos_in_archive,t.tm_mday,
+	    printf("%-25s %3d %5d %2d/%2d/%2d %2d:%02d %12s %12s\n",
+		   trunc_filename(i_data.name, s, 25),
+		   abs(i_data.f.volume), i_data.f.pos_in_archive,t.tm_mday,
 		   t.tm_mon+1, t.tm_year, t.tm_hour, t.tm_min, convert(s1, i_data.f.size),
 		   convert(s2, i_data.f.act_size));
 	    c_sz += i_data.f.act_size;
@@ -940,6 +943,7 @@ PUBLIC void taper_restore(void)
 	if (ifd.no_in_archive) {
 	    if (!get_string(win_main, rel_path, sizeof(rel_path),
 			    "Location to restore files")) return;
+	    strip_trailing_spaces(rel_path);
 	    x = select_restore_files();
 	    switch(x) {
 	       case 0:				 /* user aborted */
