@@ -1,12 +1,12 @@
 /*
-   Time-stamp: <97/08/10 12:21:30 yusuf>
+   Time-stamp: <98/05/02 17:35:38 yusuf>
 
-   $Id: sel_restore.c,v 1.49 1997/08/10 04:25:23 yusuf Exp $	
+   $Id: sel_restore.c,v 1.50 1998/05/02 12:51:41 yusuf Exp $	
 
 */
 
 #ifndef lint
-static char vcid[] = "$Id: sel_restore.c,v 1.49 1997/08/10 04:25:23 yusuf Exp $";
+static char vcid[] = "$Id: sel_restore.c,v 1.50 1998/05/02 12:51:41 yusuf Exp $";
 #endif /* lint */
 
 
@@ -80,7 +80,7 @@ void restore_update_selected_sizes()
     struct info_file_data i_data;
     struct info_file_key i_key;
     struct memory_file *m;
-
+    
     m = m_files;				 /* reset these */
     for (c=0; c<ifd.no_in_archive; c++) {
 	m->selected = 0;
@@ -100,7 +100,7 @@ void restore_update_selected_sizes()
 	}
 	else {
 	    memset(&i_key, 0, sizeof(i_key));	 /* a directory */
-	    strcpy(i_key.name, se->i.name);
+	    i_key.fname_pos = se->i.fname_pos;
 	    x = ntraverse(0, &i_key, NULL, &rec, TRAVERSE_SEARCH, INFO_NAME);
 	    se->ab_size = 0; se->mm_size = 0;
 	    /* Keep on cycling through until selections no longer match */
@@ -520,7 +520,8 @@ void make_mydir(int vol)
     else
 	strcpy(start_path, "/");
     in_dir=0;
-    memset(&i_key, 0, sizeof(i_key)); strcpy(i_key.name, start_path);
+    memset(&i_key, 0, sizeof(i_key));
+    strcpy(blank_fname, start_path); i_key.fname_pos = -1;
     if (ntraverse(0, &i_key, NULL, &c, TRAVERSE_SEARCH, INFO_NAME) == 2) return;
     while (1) {
 	if (read_info_rec(c, &i_data) == -1) return;
