@@ -1,12 +1,12 @@
 /*
-   Time-stamp: <97/08/11 18:49:59 yusuf>
+   Time-stamp: <98/06/07 11:43:11 yusuf>
 
-   $Id: select_box.c,v 1.37 1997/08/11 12:32:05 yusuf Exp $	
+   $Id: select_box.c,v 1.38 1998/06/07 04:19:42 yusuf Exp $	
 
 */
 
 #ifndef lint
-static char vcid[] = "$Id: select_box.c,v 1.37 1997/08/11 12:32:05 yusuf Exp $";
+static char vcid[] = "$Id: select_box.c,v 1.38 1998/06/07 04:19:42 yusuf Exp $";
 #endif /* lint */
 
 
@@ -847,16 +847,16 @@ int select_menu(WINDOW *win, char *menu_items[], int *in_op)
 
 
 
-char *convert(char *s, _s32 num)
+char *convert(char *s, _u32 num)
 {
 /* prints a long number in the form 123,456,789  */
     
-    sprintf(s, "%d,%03d,%03d", (int) (num/1000000L), (int) ((num%1000000L)/1000L),
-	    (int) ((num%1000000L)%1000L));
+    sprintf(s, "%lu,%03lu,%03lu", num/1000000L, (num%1000000L)/1000L,
+	    (num%1000000L)%1000L);
     if (!(num /1000000L)) 
-	sprintf(s, "%d,%03d", (int) (num/1000L), (int) (num%1000L));
+	sprintf(s, "%lu,%03lu", (num/1000L), (num%1000L));
     if (!(num / 1000L)) 			 /* number is < 1000 */
-	sprintf(s, "%d", (int) num);
+	sprintf(s, "%lu", (unsigned long) num);
     return s;
 }
 
