@@ -1,12 +1,12 @@
 /*
-   Time-stamp: <97/07/12 20:05:28 yusuf>
+   Time-stamp: <98/06/18 09:22:35 yusuf>
 
-   $Id: tapeio.c,v 1.33 1997/08/09 00:52:36 yusuf Exp $	
+   $Id: tapeio.c,v 1.35 1998/06/29 00:58:23 yusuf Exp $	
 
 */
 
 #ifndef lint
-static char vcid[] = "$Id: tapeio.c,v 1.33 1997/08/09 00:52:36 yusuf Exp $";
+static char vcid[] = "$Id: tapeio.c,v 1.35 1998/06/29 00:58:23 yusuf Exp $";
 #endif /* lint */
 
 
@@ -234,7 +234,7 @@ _errstat tape_seek(int toblock, char must_seek)
     _s32 tb;
     char s[200];
     
-    if (!can_seek) return -1;			 /* can't seek */
+    if (!can_seek && !can_fsr) return -1;	 /* can't seek or fsr */
     if (is_regfile(dv)) {
 	if (log_level > 2) write_log("File seek to correct block");
 	if (toblock < blocks_passed) return 0;
@@ -258,12 +258,25 @@ _errstat tape_seek(int toblock, char must_seek)
 	sprintf(s, "tell returned %d", tb);
 	write_log(s);
     }
-    if (log_level > 2) write_log("ioctl seek");
-    m.mt_op = MTSEEK;
-    m.mt_count = toblock+(tb-blocks_passed);
-    if (tb-blocks_passed) {
-      sprintf(s, "seek is adjusting %d", tb-blocks_passed);
-      if (log_level > 2) write_log(s);
+    if( can_fsr )
+    {
+	if (log_level > 2) write_log("ioctl fsr");
+	m.mt_op = MTFSR;
+	m.mt_count = toblock-blocks_passed;
+	if (toblock-blocks_passed) {
+	  sprintf(s, "fsr by %d records", toblock-blocks_passed);
+	  if (log_level > 2) write_log(s);
+	}
+    }
+    else if( can_seek )
+    {
+	if (log_level > 2) write_log("ioctl seek");
+	m.mt_op = MTSEEK;
+	m.mt_count = toblock+(tb-blocks_passed);
+	if (tb-blocks_passed) {
+	  sprintf(s, "seek is adjusting %d", tb-blocks_passed);
+	  if (log_level > 2) write_log(s);
+	}
     }
     if (rmtioctl(dv, MTIOCTOP, (char *) &m) != -1) {
 	blocks_passed = toblock;
@@ -629,11 +642,13 @@ _errstat tape_get_blk_size(_s32 x)
     char s[100];
     _s32 obs;
 
-    if (get_blksize) {
-	if (log_level > 2) write_log("Getting block size");
+    if (is_regfile(x)) return 0;
+
+    if (get_blksize && tape_type == TAPE_TYPE_ZFTAPE) {
+	if (log_level > 2) write_log("Getting zftape block size");
 	m.mt_blksz = block_size;
 	obs = block_size;
-	err = (is_regfile(x)) ? 0 : rmtioctl(x, MTIOC_ZFTAPE_GETBLKSZ, (char *) &m);
+	err = rmtioctl(x, MTIOC_ZFTAPE_GETBLKSZ, (char *) &m);
 	if (err == -1) 
 	 do_exit(ERROR_GETTING_BLKSIZE);
 	else
@@ -647,6 +662,28 @@ _errstat tape_get_blk_size(_s32 x)
 	else
 	  if (init_buffers(1) == -1) return -1;	 /* reallocate buffer sizes */
     }
+    else if (get_blksize) {
+        struct mtget status;
+	if (log_level > 2) write_log("Getting standard block size");
+
+	obs = block_size;
+	err = rmtioctl(x, MTIOCGET, &status);
+	if (err == -1) 
+	 do_exit(ERROR_GETTING_BLKSIZE);
+	else
+	 block_size =
+	     ((status.mt_dsreg & MT_ST_BLKSIZE_MASK) >> MT_ST_BLKSIZE_SHIFT);
+
+	sprintf(s, "Got block size %d", block_size);
+	if (log_level > 2) write_log(s);
+
+	if (block_size < 1025) {		 /* if got block size <1025, means that */
+	    block_size = obs;			 /* block size hasn't been set for this */
+	    tape_set_blk_size();		 /* volume - so set it */
+	}
+	else
+	  if (init_buffers(1) == -1) return -1;	 /* reallocate buffer sizes */
+    }
     return 0;
 }
 
@@ -1038,8 +1075,15 @@ _errstat do_next_tape(void)
     _s32 c;
     char  *my_wbuf=NULL;
     char l[200];
-    
-    if (log_level > 2) write_log("End of tape reached while writing.");
+
+    if (log_level > 2)
+	write_log("End of tape reached while writing.");
+    else
+	if ((log_level) && (no_windows)) {	 /* unattended backup */
+	    write_log("End of tape reached while writing");
+	    if (mf) write(mf, "ERROR: End of tape reached - backup aborted\n", 
+			  strlen("ERROR: End of tape reached - backup aborted\n"));
+	}
     ifd.number_tsi++;
     tsi = my_realloc(tsi, ifd.number_tsi*sizeof(struct tape_size_info));
     if (tsi == NULL) return do_exit(ERROR_MEMORY);
