@@ -1,12 +1,12 @@
 /*
-   Time-stamp: <97/08/16 17:33:46 yusuf>
+   Time-stamp: <98/06/15 13:06:59 yusuf>
 
-   $Id: taper.c,v 1.48 1997/12/28 06:48:43 yusuf Exp $	
+   $Id: taper.c,v 1.50 1998/06/29 00:58:23 yusuf Exp $	
 
 */
 
 #ifndef lint
-static char vcid[] = "$Id: taper.c,v 1.48 1997/12/28 06:48:43 yusuf Exp $";
+static char vcid[] = "$Id: taper.c,v 1.50 1998/06/29 00:58:23 yusuf Exp $";
 #endif /* lint */
 
 
@@ -386,11 +386,11 @@ PRIVATE void read_prefs_file(int argc, char *argv[])
     *pref_file = 0;
     c=1;					 /* check if command line name given */
     while (c < argc) {
-	if (!strcasecmp(argv[c], "-p") || !strcasecmp(argv[c], "--preference-file")) {
+	if (!strcmp(argv[c], "-p") || !strcasecmp(argv[c], "--preference-file")) {
 	    strcpy(pref_file,argv[c+1]);
 	    break;
 	}
-	if (!strcasecmp(argv[c], "-T") || !strcasecmp(argv[c], "--tape-type")) {
+	if (!strcmp(argv[c], "-T") || !strcasecmp(argv[c], "--tape-type")) {
 	    if (!check_a(argc, &c)) {usage(); do_exit(ERROR_USAGE);}
 	    if (set_tape_type(argv[c]) == -1)
 	      do_exit(ERROR_ILLEGAL_TAPE_TYPE);
@@ -563,6 +563,7 @@ PUBLIC _errstat fill_in_defaults()
 	if (*ntape == -1) strcpy(ntape, FTAPE_DEFAULT_NTAPE);
 	if (fast_fsf == -1) fast_fsf = 0;
 	if (can_seek == -1) can_seek = 0;
+	if (can_fsr == -1) can_fsr = 0;
 	if (set_blksize == -1) set_blksize = 0;
 	if (get_blksize == -1) get_blksize = 0;
 	if (illegal_eot == -1) illegal_eot = 0;
@@ -578,6 +579,7 @@ PUBLIC _errstat fill_in_defaults()
 	if (set_blksize == -1) set_blksize = 1;
 	if (get_blksize == -1) get_blksize = 1;
 	if (can_seek == -1) can_seek = 1;
+	if (can_fsr == -1) can_fsr = 0;
 	if (illegal_eot == -1) illegal_eot = 0;
 	have_rewind = 1;
 	have_fsf = 1;
@@ -589,6 +591,7 @@ PUBLIC _errstat fill_in_defaults()
 	if (*ntape == -1) strcpy(ntape, SCSI_DEFAULT_NTAPE);
 	if (fast_fsf == -1) fast_fsf = 1;
 	if (can_seek == -1) can_seek = 1;
+	if (can_fsr == -1) can_fsr = 1;
 	if (set_blksize == -1) set_blksize = 0;
 	if (get_blksize == -1) get_blksize = 0;
 	if (illegal_eot == -1) illegal_eot = 0;
@@ -601,6 +604,7 @@ PUBLIC _errstat fill_in_defaults()
 	if (*tape == -1) strcpy(tape, "");
 	if (*ntape == -1) strcpy(ntape, "");
 	can_seek = 1;
+	can_fsr = 0;
 	fast_fsf = 0;
 	set_blksize = 0;
 	get_blksize = 0;
@@ -615,6 +619,7 @@ PUBLIC _errstat fill_in_defaults()
 	if (*ntape == -1) strcpy(ntape, REMOVABLE_DEFAULT_NTAPE);
 	fast_fsf = 0;
 	if (can_seek == -1) can_seek = 0;
+	if (can_fsr == -1) can_fsr = 0;
 	if (illegal_eot == -1) illegal_eot = 0;
 	set_blksize = 0;
 	get_blksize = 0;
@@ -628,6 +633,7 @@ PUBLIC _errstat fill_in_defaults()
 	if (*ntape == -1) strcpy(ntape, IDE_DEFAULT_NTAPE);
 	if (fast_fsf == -1) fast_fsf = 1;
 	if (can_seek == -1) can_seek = 0;
+	if (can_fsr == -1) can_fsr = 0;
 	if (set_blksize == -1) set_blksize = 0;
 	if (get_blksize == -1) get_blksize = 0;
 	if (illegal_eot == -1) illegal_eot = 0;
@@ -659,7 +665,7 @@ PRIVATE void setup_colors(void)
 }
 
 
-PRIVATE void num_to_string(_s32 num, int rev, int top, int line, char *strings[])
+PRIVATE void num_to_string(_s32 num, int rev, int top, int step, int line, char *strings[])
 {
 /* Converts an option to a string. Num is the string assumed to
  * be selected. Strings points to an array of strings which is
@@ -686,14 +692,14 @@ PRIVATE void num_to_string(_s32 num, int rev, int top, int line, char *strings[]
 	    if (rev)
 	      wattron(win_main, A_REVERSE);
 	}
-	mvwaddstr(win_main, top+line*2, sp[c1], strings[c1]);
+	mvwaddstr(win_main, top+line*step, sp[c1], strings[c1]);
 	wattroff(win_main, A_UNDERLINE);
 	wattroff(win_main, A_REVERSE);
     }
 }
 
 
-PRIVATE void print_pref_line(struct pref_info options[], int c, int top, int rev)
+PRIVATE void print_pref_line(struct pref_info options[], int c, int top, int step, int rev)
 {
     char *py[]={"NO", "YES", NULL};
     char *pS[]={"LINK", "FILE", NULL};
@@ -705,45 +711,45 @@ PRIVATE void print_pref_line(struct pref_info options[], int c, int top, int rev
     switch(options[c].type) {
        case 'I':				 /* integer */
 	if (rev) wattron(win_main, A_REVERSE);
-	mvwprintw(win_main, top+c*2, 33, "%02d", *((_s32 *) (options[c].opt))) ; 
+	mvwprintw(win_main, top+c*step, 33, "%02d", *((_s32 *) (options[c].opt))) ; 
 	wattroff(win_main, A_REVERSE);
 	break;
        case 'B':				 /* block size */
         if (rev) wattron(win_main, A_REVERSE);
-	mvwprintw(win_main, top+c*2, 33, "%03dK", *((_s32 *) (options[c].opt))/1024) ; 
+	mvwprintw(win_main, top+c*step, 33, "%03dK", *((_s32 *) (options[c].opt))/1024) ; 
 	wattroff(win_main, A_REVERSE);
 	break;
      case 'Y':				 /* yes/no */
-	num_to_string(*((char *) options[c].opt), rev, top, c, py);
+	num_to_string(*((char *) options[c].opt), rev, top, step, c, py);
 	break;
     case 's':
-	num_to_string(*((char *) options[c].opt), rev, top, c, pS);
+	num_to_string(*((char *) options[c].opt), rev, top, step, c, pS);
 	break;
      case 'L':				 /* log level */
-	num_to_string(*((char *) options[c].opt), rev, top, c, pl);
+	num_to_string(*((char *) options[c].opt), rev, top, step, c, pl);
 	break;
      case 'C':				 /* compression type */
-	num_to_string(*((char *) options[c].opt), rev, top, c, pc);
+	num_to_string(*((char *) options[c].opt), rev, top, step, c, pc);
 	break;
        case 'O':				 /* overwrite level */
-	num_to_string(*((char *) options[c].opt), rev, top, c, po);
+	num_to_string(*((char *) options[c].opt), rev, top, step, c, po);
 	break;
      case 'T':
-	 num_to_string(*((char *) options[c].opt), rev, top, c, pt);
+	 num_to_string(*((char *) options[c].opt), rev, top, step, c, pt);
 	break;
     }
 }
 
 
-PRIVATE void print_option_screen(struct pref_info *options, int top, int count, int allab)
+PRIVATE void print_option_screen(struct pref_info *options, int top, int count, int allab, int step)
 {
     int c;
     
     for (c=0; c<count; c++) {
 	wattron(win_main, A_BOLD);
-	mvwaddstr(win_main, top+c*2, 30-strlen(options[c].name), options[c].name);
+	mvwaddstr(win_main, top+c*step, 30-strlen(options[c].name), options[c].name);
 	wattroff(win_main, A_BOLD);
-	print_pref_line(options, c, top, 0);
+	print_pref_line(options, c, top, step, 0);
     }
     (allab) ?
       centre(win_main, win_main->_maxy-1, "Arrow keys to move, F5 abort, ESC finish", COLOR_FORM) :
@@ -760,14 +766,14 @@ PRIVATE void do_left(void *v, _s32 max)
     if (*c<0) *c=max;
 }
 
-PRIVATE void change_tt_defaults(struct pref_info *options, int top, _s8 allab, FIELD *fields[])
+PRIVATE void change_tt_defaults(struct pref_info *options, int top, _s8 allab, int step, FIELD *fields[])
 {
 /* See if user wants new defaults based on this tape drive */    
     int c=0, c1;
 
     while (options[c].name)			 /* count # options */
 	c++;
-    print_option_screen(options, top, c, allab);
+    print_option_screen(options, top, c, allab, step);
     if (!message_box("Change to type defaults", MB_YESNO))
       return;
     erase_tape = -1; block_size = -1;
@@ -783,17 +789,17 @@ PRIVATE void change_tt_defaults(struct pref_info *options, int top, _s8 allab, F
     fast_fsf = -1; set_blksize = -1;
     get_blksize = -1;
     fill_in_defaults();				 /* reset defaults */
-    print_option_screen(options, top, c, allab);
+    print_option_screen(options, top, c, allab, step);
     touchwin(win_main); wrefresh(win_main);
 }
 
 
-PRIVATE void option_left(struct pref_info *options, _s32 op, int top, _s8 allab, FIELD *fields[])
+PRIVATE void option_left(struct pref_info *options, _s32 op, int top, _s8 allab,int step, FIELD *fields[])
 {
     switch(options[op].type) {
      case 'T':
 	do_left(options[op].opt, 3);
-	change_tt_defaults(options, top, allab, fields);
+	change_tt_defaults(options, top, allab, step, fields);
 	break;
      case 'L':
 	do_left(options[op].opt, 5);
@@ -821,7 +827,7 @@ PRIVATE void option_left(struct pref_info *options, _s32 op, int top, _s8 allab,
 	  *((_s32 *) options[op].opt) = 99;
 	break;
     }
-    print_pref_line(options, op, top, 1);
+    print_pref_line(options, op, top, step, 1);
 }
 
 	  
@@ -834,12 +840,12 @@ PRIVATE void do_right(void *v, _s32 max)
     if (*c>max) *c=0;
 }
       
-PRIVATE void option_right(struct pref_info *options, _s32 op, int top, _s8 allab, FIELD *fields[])
+PRIVATE void option_right(struct pref_info *options, _s32 op, int top, _s8 allab, int step, FIELD *fields[])
 {
     switch(options[op].type) {
      case 'T':
 	do_right(options[op].opt, 3);
-	change_tt_defaults(options, top, allab, fields);
+	change_tt_defaults(options, top, allab, step, fields);
 	break;
      case 'L':
 	do_right(options[op].opt, 4);
@@ -867,7 +873,7 @@ PRIVATE void option_right(struct pref_info *options, _s32 op, int top, _s8 allab
 	  *((_s32 *) options[op].opt) = 0;
 	break;
     }
-    print_pref_line(options, op, top, 1);
+    print_pref_line(options, op, top, step, 1);
 }
 
 	
@@ -925,17 +931,20 @@ PUBLIC _errstat taper_change_prefs(struct pref_info *options, _s8 allab)
     FORM *form;
     char  tmp[100];
     int   *intp;
+    int   step = 2;
 
     count=0;					 /* count number options */
     while (options[count].name) {
 	count++;
     }
     
-    top = (win_main->_maxy - (count * 2)) / 2;	 /* print screen template */
+    top = (win_main->_maxy - (count * step)) / 2;	 /* print screen template */
+    if( top < 0 ) step = 1;
+    top = (win_main->_maxy - (count * step)) / 2;	 /* print screen template */
     k1=0;
     for (c=0; c<count;c++) {			 /* now setup forms fields */
 	if (options[c].type == 'S') {
-	    fields[k1] = new_field(1, 40, top+c*2, 33, 15, 0);
+	    fields[k1] = new_field(1, 40, top+c*step, 33, 15, 0);
 	    field_opts_off(fields[k1], O_STATIC); 
 	    set_field_back(fields[k1], COLOR_PAIR(COLOR_FORM)|A_REVERSE);
 	    set_max_field(fields[k1], 0); 
@@ -943,7 +952,7 @@ PUBLIC _errstat taper_change_prefs(struct pref_info *options, _s8 allab)
 	    k1++;
 	}
 	if (options[c].type == 'N') {
-	    fields[k1] = new_field(1, 40, top+c*2, 33, 1, 0);
+	    fields[k1] = new_field(1, 40, top+c*step, 33, 1, 0);
 	    field_opts_off(fields[k1], O_STATIC); 
 	    set_field_back(fields[k1], COLOR_PAIR(COLOR_FORM)|A_REVERSE);
 	    set_max_field(fields[k1], 0); 
@@ -959,19 +968,19 @@ PUBLIC _errstat taper_change_prefs(struct pref_info *options, _s8 allab)
     set_form_win(form, win_main);  
     my_werase(win_main, COLOR_FORM); 
     post_form(form);
-    print_option_screen(options, top, count, allab);
+    print_option_screen(options, top, count, allab, step);
     c=0;
-    print_pref_line(options, c, top, 1);
+    print_pref_line(options, c, top, step, 1);
     curs_set( ((options[c].type == 'S') || (options[c].type == 'N')) ? 1: 0);
     wrefresh(win_main);
-    wmove(win_main, top+c*2, 33);
+    wmove(win_main, top+c*step, 33);
     while (1) {
 	k = wgetch(win_main);
 	if ( ((options[c].type == 'S') || (options[c].type == 'N')) && 
 	    (k != EXIT_KEY))
 	  if (do_form_driver(form, fields, k, c, count, options) == -1)
 	    continue;				 /* processed key */
-	print_pref_line(options, c, top, 0);
+	print_pref_line(options, c, top, step, 0);
 	switch(k) {
 	 case KEY_DOWN:
 	 case '\n':
@@ -1010,9 +1019,9 @@ PUBLIC _errstat taper_change_prefs(struct pref_info *options, _s8 allab)
 	    curs_set(0);
 	    return 1;
 	 case KEY_LEFT:
-	    option_left(options, c, top, allab, fields); break;
+	    option_left(options, c, top, allab, step, fields); break;
 	 case KEY_RIGHT:
-	    option_right(options, c, top, allab, fields); break;
+	    option_right(options, c, top, allab, step, fields); break;
 	 default:
 	      help = my_newwin(13, curscr->_maxx-10,
 			       (curscr->_maxy-13)/2,
@@ -1032,7 +1041,7 @@ PUBLIC _errstat taper_change_prefs(struct pref_info *options, _s8 allab)
 	      wrefresh(help);
 	      wgetch(help);
 	      my_delwin(help);
-	      print_option_screen(options, top, count, allab);
+	      print_option_screen(options, top, count, allab, step);
 	      touchwin(win_main); wrefresh(win_main);
 	      break;
 	}
@@ -1040,8 +1049,8 @@ PUBLIC _errstat taper_change_prefs(struct pref_info *options, _s8 allab)
 	if (c==count) c= 0;
 	
 	curs_set( ((options[c].type == 'S') || (options[c].type == 'N')) ? 1: 0);
-	wmove(win_main, top+c*2, 33);
-	print_pref_line(options, c, top, 1);
+	wmove(win_main, top+c*step, 33);
+	print_pref_line(options, c, top, step, 1);
 	wrefresh(win_main);
     }
     return -1;                         /* Should never get here */
@@ -1258,11 +1267,12 @@ PRIVATE void preferences_menu(void)
 	"Restore/Mkinfo preferences", "Unattended preferences",
 	"Back to main menu", NULL};
     struct pref_info tapedrive_options[] = {
-/*	{"Tape drive tape", &tape_type, 'T', 0}, */
+  	/* {"Tape drive tape", &tape_type, 'T', 0}, */
 	{"Rewinding device", tape, 'S', MAX_FNAME},
 	{"Non-rewinding device", ntape, 'S', MAX_FNAME},
 	{"Have fast fsf", &fast_fsf, 'Y', 0},
 	{"Can seek", &can_seek, 'Y', 0},  
+	{"Can fsr", &can_fsr, 'Y', 0}, 
 	{"Set block size", &set_blksize, 'Y', 0},
 	{"Get block size", &get_blksize, 'Y', 0},
 	{"Block size", &block_size, 'B', 0},
