@@ -1,12 +1,12 @@
 /*
-   Time-stamp: <98/03/03 12:29:28 yusuf>
+   Time-stamp: <98/06/15 12:55:41 yusuf>
 
-   $Id: vars.c,v 1.32 1998/03/03 04:35:11 yusuf Exp $	
+   $Id: vars.c,v 1.35 1998/06/29 00:58:24 yusuf Exp $	
 
 */
 
 #ifndef lint
-static char vcid[] = "$Id: vars.c,v 1.32 1998/03/03 04:35:11 yusuf Exp $";
+static char vcid[] = "$Id: vars.c,v 1.35 1998/06/29 00:58:24 yusuf Exp $";
 #endif /* lint */
 
 
@@ -28,6 +28,7 @@ struct pref_template ap[] = {
     {"--auto-descend", 'D', &auto_descend, NULL, 'Y', TRUE},
     {"--prompt-archive", 'e', &prompt_archive, NULL, 'Y', TRUE},	 
     {"--can-seek", 'E', &can_seek, NULL, 'Y', FALSE},  
+    {"--can-fsr", 'E', &can_fsr, NULL, 'Y', FALSE},  
     {"--tape-name", 'f', tape, NULL, 'S', FALSE},
     {"--exclude-files", 'F', exclude_files, NULL, 'S', TRUE},
     {"--volume-title", 'g', volume_title, NULL, 'S', TRUE},
@@ -57,7 +58,7 @@ struct pref_template ap[] = {
     {"--exclude-dirs", 'R', exclude_dirs, NULL, 'S', TRUE},
     {"--strip-paths", 's', &ostrip, NULL, 'I', TRUE},
     {"--set-blksize",'S', &set_blksize, NULL, 'Y', FALSE},
-    {"--archive-title", 't', archive_title, NULL, 'S'},
+    {"--archive-title", 't', archive_title, NULL, 'S', TRUE},
     {"--tape-type",  'T', &tape_type, NULL, 'T', TRUE},
     {"--incremental-backup", 'u', &incremental, NULL, 'Y', TRUE},
     {"--unattended-file", 'U', NULL, NULL, 'U', TRUE},
@@ -189,6 +190,7 @@ signed int  get_blksize=-1;			 /*   applicable to the tape */
 signed int  fast_fsf=-1;			 /*   drive selected */
 signed int  block_size=-1;			 /* is used for reading/writing data to/from tape device */
 signed int  can_seek=-1;			 /* whether tape drive can seek or not */
+signed int  can_fsr=-1;			 	 /* does the tape understand fsr&bsr ?  */
 signed int  illegal_eot=-1;			 /* how to handle end of tape */
 
 
@@ -218,6 +220,7 @@ struct info_file_header ifd;			 /* info file */
 struct volume_header *vol_headers;		 /* volume headers */
 char   *vol_details;				 /* information about volumes */
 struct tape_size_info *tsi;			 /* info about tape size */
+char blank_fname[MAX_FNAME];
 
 /* Memory allocation stuff for archive files, sel_files etc.. */
 struct selected_entry *sel_files;		 /* files selected by user */
